function xdot = PvtolSim(t,x,yref,utrim, K, pvtol, Upsilon)
%PVTOLSIM
%   xdot = PvtolSim(t, x, yref, utrim, K, pvtol, Upsilon) 
%   Returns the state derivatives for a controlled PVTOL Birotor with a  
%   state feedback controller K
%
%   Inputs
%    t = time (not used)
%    x = state vector: xvec =[z,w,x,u,theta,q]
%    yref = output reference : yref=[z,x,theta]_ref
%    utrim = control and disturbance trim values : uvec=[Omega1+Omega2,Omega1-Omega2,Vw]
%    K = state feedback controller
%    pvtol = vehicle airframe & rotor coefficients structure (see Coefficients.m) 
%    Upsilon = rotor tilt angle (rad) 
% 

%   (c) James Whidborne
%   Cranfield University, 16 August 2020
 
e = [yref(1)-x(1);-x(2);yref(2)-x(3);-x(4);yref(3)-x(5);-x(6)]; % state error
u = [ K*e; 0]+utrim'; % control + wind disturbance
[xdot] = PvtolDynamics(x, u, pvtol, Upsilon); % state derivatives
end






