function [ A,B,xtrim,utrim ] = PvtolTrimLin( pvtol,Vw,Upsilon,xtrim0,utrim0,trimoptions)
%PVTOLTRIMLIN
%   [A,B,xtrim,utrim] = PvtolTrimLin(pvtol,Vh,Upsilon,rho,xtrim,utrim,trimoptions)
%   Trim and linearize PVTOL birotor dynamics + aerodynamics model
%
%   Inputs:
%     pvtol = pvtol coefficients structure (see Coefficients.m) 
%     Vw = horizontal wind speed (m/s)
%     Upsilon = rotor tilt angle (rad) 
%     xtrim0 = trim state guess initial value  xvec=[z,zdot,x,xdot,theta,q]
%     utrim0 = trim control guess initial value  uvec=[Omegal+Omegar,Omegal-Omegar,Vw] 
%     trimoptions: options vector for fzero
%
%   Outputs:
%     A = small perturbation model state matrix
%     B = small perturbation model input matrix  
%     xtrim = trim state  xvec=[z,zdot,x,xdot,theta,q]
%     utrim = trim control uvec=[Omegal+Omegar,Omegal-Omegar,Vw]

%   (c) James Whidborne
%   Cranfield University, 18 August 2020

    xttrim0 = [xtrim0(5),utrim0(1),utrim0(2)];% trim vector guess [phi, omegal+omegar,omegal-omegar]
    [xttrim ,fmin] = fminsearch(@(xt) PvtolTrim(xt,pvtol,Vw,Upsilon),xttrim0,trimoptions);
    if(fmin>1e-10),warning(['fmin = ',num2str(fmin)]),end
    thetatrim = xttrim(1);     % trim roll angle
%    Omegaltrim=xttrim(2); % trim left rotor speed
%    Omegartrim=xttrim(3); % trim right rotor speed

    %% linearize
    f = @(x,u) PvtolDynamics(x, u, pvtol, Upsilon);
    xtrim = [0,0,0,0,thetatrim,0];       % x=[z,zdot,x,xdot,theta,q] 
    utrim = [xttrim(2),xttrim(3),Vw];    % u=[Omegal+Omegar,Omegal-Omegar,Vw]
    [A,B] = LinearizeAB(f,xtrim,utrim);  % linearize

end

