function [e] = QuadrotorTrim(xt,p,wind)
%QUADROTORTRIM
%    e = QuadrotorTrim(x,u,p,wind)
%    Calculate trim residual for quadrotor 
%    
%    Inputs:
%    xt = trim vector: [u v w phi theta psi p q r Omega1 Omega2 Omega3 Omega4] 
%    p = quadrotor coefficients structure (see Coefficients.m)
%    wind = wind disturbance vector
%
%    Output: 
%    e: residual 
%

%   (c) James Whidborne
%   Cranfield University, 18 August 2020

g=9.81;   % gravitational constant (m/s^2)
x=[zeros(3,1);xt(1:9)];
u=xt(10:13); 
Omega=u;

xdot=QuadrotorDynamics(x,Omega,p,wind);
e = xdot'*xdot; % square and sum
end
