function [ A,B,xtrim,utrim ] = QuadrotorTrimLin(quad,wind,xtrim0,utrim0,trimoptions)
%QUADROTORTRIMLIN
%   [A,B,xtrim,utrim] = QuadrotorTrimLin(quad,wind,xtrim0,utrim0,trimoptions)
%   Trim and linearize quadrotor dynamics  
%
%   Inputs
%    quad = quadrotor coefficients structure (see Coefficients.m)
%    wind = wind disturbance vector
%    xtrim0 = trim guess initial value:[xe ye ze u v w phi theta psi p q r]
%    utrim0 = control trim initial value guess (4 rotor speeds) 
%    trimoptions: options vector for fzero
%
%   Outputs:
%    A = small perturbation model state matrix
%    B = small perturbation model input matrix
%    xtrim = trim state  xvec=[xe ye ze u v w phi theta psi p q r]
%    utrim = trim control uvec=[Omega1,Omega2,Omega3,Omega4]
%

%   (c) James Whidborne
%   Cranfield University, 16 August 2020
 
xttrim0=[xtrim0(4:12);utrim0];% trim vector guess
[xttrim ,fmin]=fminsearch(@(xt) QuadrotorTrim(xt,quad,wind),xttrim0,trimoptions);
if(fmin>1e-10),warning(['fmin = ',num2str(fmin)]),end

xtrim = [zeros(3,1);xttrim(1:9)];
utrim = xttrim(10:13);
Omegatrim = utrim; % trim rotor   speed
%% linearize
f = @(x,u) QuadrotorDynamics(x,u,quad,wind);
[A,B] = LinearizeAB(f,xtrim,Omegatrim);   % linearize

end

