function [CH,CQ]=RotorCHQ(T,alpha,V,Omega,rho,rotor)
%ROTORCHQ
%   [CH,CQ]=RotorCHQ(T,alpha,V,Omega,rho,rotor)
%   Returns rotor  drag and torque coefficients CH and CQ
%   the subsequent drag is calculated from 
%      H = rho*A*(Omega*rotor.R)^2*CH(T,alpha,V,Omega,rho,rotor)
%   and torque from 
%      Q = rho*A*Omega^2*rotor.R^3*CQ(T,alpha,V,Omega,rho,rotor)
%
%   CH: rotor drag coefficient 
%   CQ: rotor torque coefficient 
% 
%   T: rotor thrust
%   alpha : angle of attack/wind incidence angle (rad)
%   V : incident windspeed (m/s)
%   Omega : rotor speed (rad/sec)
%   rho: air density (kg/m^3)
%   rotor: vehicle rotor coefficients structure (see AircraftCoefficients.m) 

%   (c) James Whidborne
%   Cranfield University, 27 February 2019 
   
[~,CH,CQ]=RotorC(T,alpha,V,Omega,rho,rotor); % Returns rotor thrust coefficient

end


