function [CT]=RotorCT(T,alpha,V,Omega,rho,rotor)
%ROTORCT
%   [CT]=RotorCT(T,alpha,V,Omega,rho,rotor)
%   Returns rotor thrust coefficient CT(T) 
%   the subsequent thrust is calculated from
%      T = rho*A*(Omega*rotor.R)^2*CT(T,alphar,V,Omega,rho,rotor) 
%   NOTE that this is an implicit equation and must be solved iteratively
%   using fzero.m or similar
%
%   CT: rotor thrust coefficient 
% 
%   T: rotor thrust
%   alpha : angle of attack/wind incidence angle (rad)
%   V : incident windspeed (m/s)
%   Omega : rotor speed (rad/sec)
%   rho: air density (kg/m^3)
%   rotor: vehicle rotor coefficients structure (see Coefficients.m) 

%   (c) James Whidborne
%   Cranfield University, 19 August 2020 

[CT,~]=RotorC(T,alpha,V,Omega,rho,rotor); % Returns rotor thrust coefficient

end


