% Visualize_birotor.m
% 13/3/21
function Visualize_pvtol(x,y,theta,w,Upsilon,mv)
% x is horixzontal trajectory
% y is horixzontal trajectory
% phi is pitch/roll
% w is horizontal wind speed

if nargin<6, mv = [],end % if recording video
figure1 = figure(100);
set(figure1,'Position',[52 217 1140 418]);

% Create axes
axes1 = axes('Parent',figure1);
hold(axes1,'on');
Vl = 0.450;        % arm length
VR = 0.258;        % rotor diameter
V = [-Vl,Vl; 0 0]; % arms
V1 = [cos(Upsilon),-sin(Upsilon);sin(Upsilon),cos(Upsilon)]*[-VR,+VR;0, 0]-[Vl Vl;0 0]; % left rotor
V2 = [cos(-Upsilon),-sin(-Upsilon);sin(-Upsilon),cos(-Upsilon)]*[-VR,+VR;0, 0]+[Vl Vl;0 0]; % right rotor

% Create vehicle plot
v = plot(V(1,:),V(2,:),'LineWidth',2,'Color',[0.2 0.2 0.2]); % arms
v1 = plot(V1(1,:),V1(2,:),'LineWidth',6,'Color',[0 0.1 0.9]); % left rotor
v2 = plot(V2(1,:),V2(2,:),'LineWidth',6,'Color',[0 0.1 0.9]);% right rotor 

% preserve the limits of the axes
xlim(axes1,[-7.0, 9.0]);ylim(axes1,[-2,3]);box(axes1,'on');
xlabel('horizontal position $x$ (m)','Interpreter' ,'Latex','fontsize',14)
ylabel('altitude $h$ (m)','Interpreter' ,'Latex','fontsize',14)
% Set the remaining axes properties
set(axes1,'DataAspectRatio',[1 1 1],'PlotBoxAspectRatio',[434 342.3 171.15],...
    'XGrid','on','XTick',[-7 -6 -5 -4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9],...
    'YGrid','on','YTick',[-2 -1 0 1 2 3]);
t = title(['$\Upsilon=  ',num2str(Upsilon*180/pi),'^\circ$'],'Interpreter','Latex','FontSize',16);

for i=1:length(theta)
    R=[cos(theta(i)),-sin(theta(i));sin(theta(i)),cos(theta(i))]; % pitch/roll
    VV=R*V;VV1=R*V1;VV2=R*V2;
    v.XData=VV(1,:)+x(i); % arms
    v.YData=VV(2,:)+y(i);
    v1.XData=VV1(1,:)+x(i); % left rotor
    v1.YData=VV1(2,:)+y(i);
    v2.XData=VV2(1,:)+x(i); % right rotor
    v2.YData=VV2(2,:)+y(i); 
    if(i==1)
        pause(5)
    else
        pause(.001)
    end
    if isa(mv,'VideoWriter'), frame = getframe(gcf);
        writeVideo(mv,frame);
        if(i==1)
            for ii=1:35 % add a 1sec wait at start
                writeVideo(mv,frame);
            end
            
            h9=annotation(figure1,'textarrow',[0.58, 0.68 ],...
                [0.3 0.3],'String',{'Wind'});
        end
    end
    %redraw
end
pause
delete(h9)
delete(t)
return

